@@ -5,7 +5,7 @@ import shutil
 import textwrap
 from hashlib import sha256
 from pathlib import Path
-from typing import Callable, List, Tuple
+from typing import Callable
 
 import pytest
 
@@ -670,7 +670,7 @@ def test_download__python_version_used_for_python_requires(
     )
     wheel_dir = os.path.dirname(wheel_path)
 
-    def make_args(python_version: str) -> List[str]:
+    def make_args(python_version: str) -> list[str]:
         return [
             "download",
             "--no-index",
@@ -1101,7 +1101,9 @@ def test_download_file_url_existing_ok_download(
     simple_pkg = shared_data.packages / "simple-1.0.tar.gz"
     url = f"{simple_pkg.as_uri()}#sha256={sha256(downloaded_path_bytes).hexdigest()}"
 
-    shared_script.pip("download", "-d", str(download_dir), url)
+    shared_script.pip(
+        "download", "-d", str(download_dir), url, "--disable-pip-version-check"
+    )
 
     assert downloaded_path_bytes == downloaded_path.read_bytes()
 
@@ -1240,14 +1242,14 @@ def download_local_html_index(
     script: PipTestEnvironment,
     html_index_for_packages: Path,
     tmpdir: Path,
-) -> Callable[..., Tuple[TestPipResult, Path]]:
+) -> Callable[..., tuple[TestPipResult, Path]]:
     """Execute `pip download` against a generated PyPI index."""
     download_dir = tmpdir / "download_dir"
 
     def run_for_generated_index(
-        args: List[str],
+        args: list[str],
         allow_error: bool = False,
-    ) -> Tuple[TestPipResult, Path]:
+    ) -> tuple[TestPipResult, Path]:
         """
         Produce a PyPI directory structure pointing to the specified packages, then
         execute `pip download -i ...` pointing to our generated index.
@@ -1271,14 +1273,14 @@ def download_server_html_index(
     script: PipTestEnvironment,
     tmpdir: Path,
     html_index_with_onetime_server: http.server.ThreadingHTTPServer,
-) -> Callable[..., Tuple[TestPipResult, Path]]:
+) -> Callable[..., tuple[TestPipResult, Path]]:
     """Execute `pip download` against a generated PyPI index."""
     download_dir = tmpdir / "download_dir"
 
     def run_for_generated_index(
-        args: List[str],
+        args: list[str],
         allow_error: bool = False,
-    ) -> Tuple[TestPipResult, Path]:
+    ) -> tuple[TestPipResult, Path]:
         """
         Produce a PyPI directory structure pointing to the specified packages, then
         execute `pip download -i ...` pointing to our generated index.
@@ -1313,9 +1315,9 @@ def download_server_html_index(
     ],
 )
 def test_download_metadata(
-    download_local_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_local_html_index: Callable[..., tuple[TestPipResult, Path]],
     requirement_to_download: str,
-    expected_outputs: List[str],
+    expected_outputs: list[str],
 ) -> None:
     """Verify that if a data-dist-info-metadata attribute is present, then it is used
     instead of the actual dist's METADATA."""
@@ -1350,9 +1352,9 @@ def test_download_metadata(
     ],
 )
 def test_download_metadata_server(
-    download_server_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_server_html_index: Callable[..., tuple[TestPipResult, Path]],
     requirement_to_download: str,
-    expected_outputs: List[str],
+    expected_outputs: list[str],
     doubled_path: str,
 ) -> None:
     """Verify that if a data-dist-info-metadata attribute is present, then it is used
@@ -1390,7 +1392,7 @@ def test_download_metadata_server(
     ],
 )
 def test_incorrect_metadata_hash(
-    download_local_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_local_html_index: Callable[..., tuple[TestPipResult, Path]],
     requirement_to_download: str,
     real_hash: str,
 ) -> None:
@@ -1415,7 +1417,7 @@ def test_incorrect_metadata_hash(
     ],
 )
 def test_metadata_not_found(
-    download_local_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_local_html_index: Callable[..., tuple[TestPipResult, Path]],
     requirement_to_download: str,
     expected_url: str,
 ) -> None:
@@ -1435,7 +1437,7 @@ def test_metadata_not_found(
 
 
 def test_produces_error_for_mismatched_package_name_in_metadata(
-    download_local_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_local_html_index: Callable[..., tuple[TestPipResult, Path]],
 ) -> None:
     """Verify that the package name from the metadata matches the requested package."""
     result, _ = download_local_html_index(
@@ -1458,7 +1460,7 @@ def test_produces_error_for_mismatched_package_name_in_metadata(
     ],
 )
 def test_canonicalizes_package_name_before_verifying_metadata(
-    download_local_html_index: Callable[..., Tuple[TestPipResult, Path]],
+    download_local_html_index: Callable[..., tuple[TestPipResult, Path]],
     requirement: str,
 ) -> None:
     """Verify that the package name from the command line and the package's
