@@ -2,7 +2,7 @@ import os
 import pathlib
 import sys
 import textwrap
-from typing import TYPE_CHECKING, Callable, Dict, List, Protocol, Tuple
+from typing import TYPE_CHECKING, Callable, Protocol
 
 import pytest
 from packaging.utils import canonicalize_name
@@ -632,8 +632,8 @@ def test_new_resolver_force_reinstall(script: PipTestEnvironment) -> None:
 )
 def test_new_resolver_handles_prerelease(
     script: PipTestEnvironment,
-    available_versions: List[str],
-    pip_args: List[str],
+    available_versions: list[str],
+    pip_args: list[str],
     expected_version: str,
 ) -> None:
     for version in available_versions:
@@ -659,7 +659,7 @@ def test_new_resolver_handles_prerelease(
     ],
 )
 def test_new_resolver_skips_marker(
-    script: PipTestEnvironment, pkg_deps: List[str], root_deps: List[str]
+    script: PipTestEnvironment, pkg_deps: list[str], root_deps: list[str]
 ) -> None:
     create_basic_wheel_for_package(script, "pkg", "1.0", depends=pkg_deps)
     create_basic_wheel_for_package(script, "dep", "1.0")
@@ -686,7 +686,7 @@ def test_new_resolver_skips_marker(
     ],
 )
 def test_new_resolver_constraints(
-    script: PipTestEnvironment, constraints: List[str]
+    script: PipTestEnvironment, constraints: list[str]
 ) -> None:
     create_basic_wheel_for_package(script, "pkg", "1.0")
     create_basic_wheel_for_package(script, "pkg", "2.0")
@@ -952,8 +952,8 @@ if TYPE_CHECKING:
             script: PipTestEnvironment,
             name: str,
             version: str,
-            requires: List[str],
-            extras: Dict[str, List[str]],
+            requires: list[str],
+            extras: dict[str, list[str]],
         ) -> str: ...
 
 
@@ -961,8 +961,8 @@ def _local_with_setup(
     script: PipTestEnvironment,
     name: str,
     version: str,
-    requires: List[str],
-    extras: Dict[str, List[str]],
+    requires: list[str],
+    extras: dict[str, list[str]],
 ) -> str:
     """Create the package as a local source directory to install from path."""
     path = create_test_package_with_setup(
@@ -979,8 +979,8 @@ def _direct_wheel(
     script: PipTestEnvironment,
     name: str,
     version: str,
-    requires: List[str],
-    extras: Dict[str, List[str]],
+    requires: list[str],
+    extras: dict[str, list[str]],
 ) -> str:
     """Create the package as a wheel to install from path directly."""
     path = create_basic_wheel_for_package(
@@ -997,8 +997,8 @@ def _wheel_from_index(
     script: PipTestEnvironment,
     name: str,
     version: str,
-    requires: List[str],
-    extras: Dict[str, List[str]],
+    requires: list[str],
+    extras: dict[str, list[str]],
 ) -> str:
     """Create the package as a wheel to install from index."""
     create_basic_wheel_for_package(
@@ -1855,7 +1855,7 @@ def test_new_resolver_succeeds_on_matching_constraint_and_requirement(
     constraints_file = script.scratch_path / "constraints.txt"
     constraints_file.write_text(req_line)
 
-    last_args: Tuple[str, ...]
+    last_args: tuple[str, ...]
     if editable:
         last_args = ("-e", os.fspath(source_dir))
     else:
@@ -2320,7 +2320,7 @@ def test_new_resolver_dont_backtrack_on_extra_if_base_constrained_in_requirement
         script, "pkg", "2.0", extras={"ext1": ["dep"], "ext2": ["dep"]}
     )
 
-    to_install: Tuple[str, str] = (
+    to_install: tuple[str, str] = (
         "pkg[ext1]",
         "pkg[ext2]==1.0" if two_extras else "pkg==1.0",
     )
@@ -2367,7 +2367,7 @@ def test_new_resolver_dont_backtrack_on_conflicting_constraints_on_extras(
         script, "pkg", "2.0", extras={"ext1": ["dep"], "ext2": ["dep"]}
     )
 
-    to_install: Tuple[str, str] = (
+    to_install: tuple[str, str] = (
         "pkg[ext1]>1",
         "pkg[ext2]==1.0" if two_extras else "pkg==1.0",
     )
@@ -2531,7 +2531,7 @@ def test_new_resolver_comes_from_with_extra(
     create_basic_wheel_for_package(script, "dep", "1.0")
     create_basic_wheel_for_package(script, "pkg", "1.0", extras={"ext": ["dep"]})
 
-    to_install: Tuple[str, str] = ("pkg", "pkg[ext]")
+    to_install: tuple[str, str] = ("pkg", "pkg[ext]")
 
     result = script.pip(
         "install",
