@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import json
 import os
 import pathlib
@@ -8,33 +10,20 @@ import subprocess
 import sys
 import textwrap
 from base64 import urlsafe_b64encode
+from collections.abc import Iterable, Iterator, Mapping
 from contextlib import contextmanager
 from hashlib import sha256
 from io import BytesIO, StringIO
 from textwrap import dedent
-from typing import (
-    Any,
-    AnyStr,
-    Callable,
-    Dict,
-    Iterable,
-    Iterator,
-    List,
-    Literal,
-    Mapping,
-    Optional,
-    Protocol,
-    Tuple,
-    Union,
-    cast,
-)
-from urllib.parse import urlparse, urlunparse
+from typing import Any, AnyStr, Callable, Literal, Protocol, Union, cast
+from urllib.request import pathname2url
 from zipfile import ZipFile
 
 import pytest
-from pip._vendor.packaging.utils import canonicalize_name
 from scripttest import FoundDir, FoundFile, ProcResult, TestFileEnvironment
 
+from pip._vendor.packaging.utils import canonicalize_name
+
 from pip._internal.cli.main import main as pip_entry_point
 from pip._internal.index.collector import LinkCollector
 from pip._internal.index.package_finder import PackageFinder
@@ -44,6 +33,7 @@ from pip._internal.models.selection_prefs import SelectionPreferences
 from pip._internal.models.target_python import TargetPython
 from pip._internal.network.session import PipSession
 from pip._internal.utils.egg_link import _egg_link_names
+
 from tests.lib.venv import VirtualEnvironment
 from tests.lib.wheel import make_wheel
 
@@ -57,14 +47,14 @@ pyversion = get_major_minor_version()
 CURRENT_PY_VERSION_INFO = sys.version_info[:3]
 
 _Test = Callable[..., None]
-_FilesState = Dict[str, Union[FoundDir, FoundFile]]
+_FilesState = dict[str, Union[FoundDir, FoundFile]]
 
 
 def assert_paths_equal(actual: str, expected: str) -> None:
     assert os.path.normpath(actual) == os.path.normpath(expected)
 
 
-def create_file(path: str, contents: Optional[str] = None) -> None:
+def create_file(path: str, contents: str | None = None) -> None:
     """Create a file on the path, with the given contents"""
     from pip._internal.utils.misc import ensure_dir
 
@@ -77,8 +67,8 @@ def create_file(path: str, contents: Optional[str] = None) -> None:
 
 
 def make_test_search_scope(
-    find_links: Optional[List[str]] = None,
-    index_urls: Optional[List[str]] = None,
+    find_links: list[str] | None = None,
+    index_urls: list[str] | None = None,
 ) -> SearchScope:
     if find_links is None:
         find_links = []
@@ -93,9 +83,9 @@ def make_test_search_scope(
 
 
 def make_test_link_collector(
-    find_links: Optional[List[str]] = None,
-    index_urls: Optional[List[str]] = None,
-    session: Optional[PipSession] = None,
+    find_links: list[str] | None = None,
+    index_urls: list[str] | None = None,
+    session: PipSession | None = None,
 ) -> LinkCollector:
     """
     Create a LinkCollector object for testing purposes.
@@ -112,11 +102,11 @@ def make_test_link_collector(
 
 
 def make_test_finder(
-    find_links: Optional[List[str]] = None,
-    index_urls: Optional[List[str]] = None,
+    find_links: list[str] | None = None,
+    index_urls: list[str] | None = None,
     allow_all_prereleases: bool = False,
-    session: Optional[PipSession] = None,
-    target_python: Optional[TargetPython] = None,
+    session: PipSession | None = None,
+    target_python: TargetPython | None = None,
 ) -> PackageFinder:
     """
     Create a PackageFinder for testing purposes.
@@ -155,13 +145,13 @@ class TestData:
     def __init__(
         self,
         root: pathlib.Path,
-        source: Optional[pathlib.Path] = None,
+        source: pathlib.Path | None = None,
     ) -> None:
         self.source = source or DATA_DIR
         self.root = root.resolve()
 
     @classmethod
-    def copy(cls, root: pathlib.Path) -> "TestData":
+    def copy(cls, root: pathlib.Path) -> TestData:
         obj = cls(root)
         obj.reset()
         return obj
@@ -302,7 +292,7 @@ class TestPipResult:
     def files_deleted(self) -> FoundFiles:
         return FoundFiles(self._impl.files_deleted)
 
-    def _get_egg_link_path_created(self, egg_link_paths: List[str]) -> Optional[str]:
+    def _get_egg_link_path_created(self, egg_link_paths: list[str]) -> str | None:
         for egg_link_path in egg_link_paths:
             if egg_link_path in self.files_created:
                 return egg_link_path
@@ -312,11 +302,11 @@ class TestPipResult:
         self,
         pkg_name: str,
         editable: bool = True,
-        with_files: Optional[List[str]] = None,
-        without_files: Optional[List[str]] = None,
+        with_files: list[str] | None = None,
+        without_files: list[str] | None = None,
         without_egg_link: bool = False,
         use_user_site: bool = False,
-        sub_dir: Optional[str] = None,
+        sub_dir: str | None = None,
     ) -> None:
         with_files = with_files or []
         without_files = without_files or []
@@ -412,20 +402,20 @@ class TestPipResult:
                     f"Package directory {pkg_dir!r} has unexpected content {f}"
                 )
 
-    def did_create(self, path: StrPath, message: Optional[str] = None) -> None:
+    def did_create(self, path: StrPath, message: str | None = None) -> None:
         assert path in self.files_created, _one_or_both(message, self)
 
-    def did_not_create(self, p: StrPath, message: Optional[str] = None) -> None:
+    def did_not_create(self, p: StrPath, message: str | None = None) -> None:
         assert p not in self.files_created, _one_or_both(message, self)
 
-    def did_update(self, path: StrPath, message: Optional[str] = None) -> None:
+    def did_update(self, path: StrPath, message: str | None = None) -> None:
         assert path in self.files_updated, _one_or_both(message, self)
 
-    def did_not_update(self, p: StrPath, message: Optional[str] = None) -> None:
+    def did_not_update(self, p: StrPath, message: str | None = None) -> None:
         assert p not in self.files_updated, _one_or_both(message, self)
 
 
-def _one_or_both(a: Optional[str], b: Any) -> str:
+def _one_or_both(a: str | None, b: Any) -> str:
     """Returns f"{a}\n{b}" if a is truthy, else returns str(b)."""
     if not a:
         return str(b)
@@ -471,9 +461,7 @@ def _check_stderr(
         # sent directly to stderr and so bypass any configured log formatter.
         # The "--- Logging error ---" string is used in Python 3.4+, and
         # "Logged from file " is used in Python 2.
-        if line.startswith("--- Logging error ---") or line.startswith(
-            "Logged from file "
-        ):
+        if line.startswith(("--- Logging error ---", "Logged from file ")):
             reason = "stderr has a logging error, which is never allowed"
             msg = make_check_stderr_message(stderr, line=line, reason=reason)
             raise RuntimeError(msg)
@@ -522,7 +510,7 @@ class PipTestEnvironment(TestFileEnvironment):
         *args: Any,
         virtualenv: VirtualEnvironment,
         pip_expect_warning: bool = False,
-        zipapp: Optional[str] = None,
+        zipapp: str | None = None,
         **kwargs: Any,
     ) -> None:
         # Store paths related to the virtual environment
@@ -604,7 +592,7 @@ class PipTestEnvironment(TestFileEnvironment):
         self.user_site_path.joinpath("easy-install.pth").touch()
 
     def _ignore_file(self, fn: str) -> bool:
-        if fn.endswith("__pycache__") or fn.endswith(".pyc"):
+        if fn.endswith(("__pycache__", ".pyc")):
             result = True
         elif self.zipapp and fn.endswith("cacert.pem"):
             # Temporary copies of cacert.pem are extracted
@@ -614,7 +602,7 @@ class PipTestEnvironment(TestFileEnvironment):
             result = super()._ignore_file(fn)
         return result
 
-    def _find_traverse(self, path: str, result: Dict[str, FoundDir]) -> None:
+    def _find_traverse(self, path: str, result: dict[str, FoundDir]) -> None:
         # Ignore symlinked directories to avoid duplicates in `run()`
         # results because of venv `lib64 -> lib/` symlink on Linux.
         full = os.path.join(self.base_path, path)
@@ -627,9 +615,9 @@ class PipTestEnvironment(TestFileEnvironment):
     def run(
         self,
         *args: str,
-        cwd: Optional[StrPath] = None,
-        allow_stderr_error: Optional[bool] = None,
-        allow_stderr_warning: Optional[bool] = None,
+        cwd: StrPath | None = None,
+        allow_stderr_error: bool | None = None,
+        allow_stderr_warning: bool | None = None,
         allow_error: bool = False,
         **kw: Any,
     ) -> TestPipResult:
@@ -774,7 +762,7 @@ class PipTestEnvironment(TestFileEnvironment):
 # multiple commands.  Maybe should be rolled into ScriptTest?
 def diff_states(
     start: _FilesState, end: _FilesState, ignore: Iterable[StrPath] = ()
-) -> Dict[str, _FilesState]:
+) -> dict[str, _FilesState]:
     """
     Differences two "filesystem states" as represented by dictionaries
     of FoundFile and FoundDir objects.
@@ -818,10 +806,10 @@ def diff_states(
 
 
 def assert_all_changes(
-    start_state: Union[_FilesState, TestPipResult],
-    end_state: Union[_FilesState, TestPipResult],
-    expected_changes: List[StrPath],
-) -> Dict[str, _FilesState]:
+    start_state: _FilesState | TestPipResult,
+    end_state: _FilesState | TestPipResult,
+    expected_changes: list[StrPath],
+) -> dict[str, _FilesState]:
     """
     Fails if anything changed that isn't listed in the
     expected_changes.
@@ -858,8 +846,8 @@ def assert_all_changes(
 
 def _create_main_file(
     dir_path: pathlib.Path,
-    name: Optional[str] = None,
-    output: Optional[str] = None,
+    name: str | None = None,
+    output: str | None = None,
 ) -> None:
     """
     Create a module with a main() function that prints the given output.
@@ -881,7 +869,7 @@ def _create_main_file(
 def _git_commit(
     env_or_script: PipTestEnvironment,
     repo_dir: StrPath,
-    message: Optional[str] = None,
+    message: str | None = None,
     allow_empty: bool = False,
     stage_modified: bool = False,
 ) -> None:
@@ -1174,10 +1162,10 @@ def create_basic_wheel_for_package(
     script: PipTestEnvironment,
     name: str,
     version: str,
-    depends: Optional[List[str]] = None,
-    extras: Optional[Dict[str, List[str]]] = None,
-    requires_python: Optional[str] = None,
-    extra_files: Optional[Dict[str, Union[bytes, str]]] = None,
+    depends: list[str] | None = None,
+    extras: dict[str, list[str]] | None = None,
+    requires_python: str | None = None,
+    extra_files: dict[str, bytes | str] | None = None,
 ) -> pathlib.Path:
     if depends is None:
         depends = []
@@ -1208,7 +1196,7 @@ def create_basic_wheel_for_package(
         for package in packages
     ]
 
-    metadata_updates: Dict[str, Any] = {
+    metadata_updates: dict[str, Any] = {
         "Provides-Extra": list(extras),
         "Requires-Dist": requires_dist,
     }
@@ -1234,11 +1222,11 @@ def create_basic_sdist_for_package(
     script: PipTestEnvironment,
     name: str,
     version: str,
-    extra_files: Optional[Dict[str, str]] = None,
+    extra_files: dict[str, str] | None = None,
     *,
     fails_egg_info: bool = False,
     fails_bdist_wheel: bool = False,
-    depends: Optional[List[str]] = None,
+    depends: list[str] | None = None,
     setup_py_prelude: str = "",
 ) -> pathlib.Path:
     files = {
@@ -1298,7 +1286,7 @@ def create_basic_sdist_for_package(
     return retval
 
 
-def need_executable(name: str, check_cmd: Tuple[str, ...]) -> Callable[[_Test], _Test]:
+def need_executable(name: str, check_cmd: tuple[str, ...]) -> Callable[[_Test], _Test]:
     def wrapper(fn: _Test) -> _Test:
         try:
             subprocess.check_output(check_cmd)
@@ -1348,7 +1336,7 @@ class InMemoryPipResult:
 
 
 class InMemoryPip:
-    def pip(self, *args: Union[str, pathlib.Path]) -> InMemoryPipResult:
+    def pip(self, *args: str | pathlib.Path) -> InMemoryPipResult:
         orig_stdout = sys.stdout
         stdout = StringIO()
         sys.stdout = stdout
@@ -1370,25 +1358,25 @@ class ScriptFactory(Protocol):
     def __call__(
         self,
         tmpdir: pathlib.Path,
-        virtualenv: Optional[VirtualEnvironment] = None,
-        environ: Optional[Dict[AnyStr, AnyStr]] = None,
+        virtualenv: VirtualEnvironment | None = None,
+        environ: dict[AnyStr, AnyStr] | None = None,
     ) -> PipTestEnvironment: ...
 
 
 CertFactory = Callable[[], str]
 
-# versions containing fix/backport from https://github.com/python/cpython/pull/113563
-# which changed the behavior of `urllib.parse.urlun{parse,split}`
-url = "////path/to/file"
-has_new_urlun_behavior = url == urlunparse(urlparse(url))
+# -------------------------------------------------------------------------
+# Accommodations for Windows path and URL changes in recent Python releases
+# -------------------------------------------------------------------------
 
-# the above change seems to only impact tests on Windows, so just add skips for that
-skip_needs_new_urlun_behavior_win = pytest.mark.skipif(
-    sys.platform != "win32" or not has_new_urlun_behavior,
-    reason="testing windows behavior for newer CPython",
+# Trailing slashes are now preserved on Windows, matching POSIX behaviour.
+# BPO: https://github.com/python/cpython/issues/126212
+does_pathname2url_preserve_trailing_slash = pathname2url("C:\\foo\\").endswith("/")
+skip_needs_new_pathname2url_trailing_slash_behavior_win = pytest.mark.skipif(
+    sys.platform != "win32" or not does_pathname2url_preserve_trailing_slash,
+    reason="testing windows (pathname2url) behavior for newer CPython",
 )
-
-skip_needs_old_urlun_behavior_win = pytest.mark.skipif(
-    sys.platform != "win32" or has_new_urlun_behavior,
-    reason="testing windows behavior for older CPython",
+skip_needs_old_pathname2url_trailing_slash_behavior_win = pytest.mark.skipif(
+    sys.platform != "win32" or does_pathname2url_preserve_trailing_slash,
+    reason="testing windows (pathname2url) behavior for older CPython",
 )
