@@ -1,5 +1,4 @@
-"""Tests for all things related to the configuration
-"""
+"""Tests for all things related to the configuration"""
 
 import re
 from unittest.mock import MagicMock
@@ -8,6 +7,7 @@ import pytest
 
 from pip._internal.configuration import get_configuration_files, kinds
 from pip._internal.exceptions import ConfigurationError
+
 from tests.lib.configuration_helpers import ConfigurationMixin
 
 
