@@ -1,7 +1,9 @@
+from __future__ import annotations
+
 import logging
-from typing import FrozenSet, List, Optional, Set, Tuple
 
 import pytest
+
 from pip._vendor.packaging.specifiers import SpecifierSet
 from pip._vendor.packaging.tags import Tag
 
@@ -25,6 +27,7 @@ from pip._internal.models.target_python import TargetPython
 from pip._internal.network.session import PipSession
 from pip._internal.utils.compatibility_tags import get_supported
 from pip._internal.utils.hashes import Hashes
+
 from tests.lib import CURRENT_PY_VERSION_INFO
 from tests.lib.index import make_mock_candidate
 
@@ -80,7 +83,7 @@ def check_caplog(
 def test_check_link_requires_python__incompatible_python(
     caplog: pytest.LogCaptureFixture,
     ignore_requires_python: bool,
-    expected: Tuple[bool, str, str],
+    expected: tuple[bool, str, str],
 ) -> None:
     """
     Test an incompatible Python.
@@ -130,7 +133,7 @@ class TestLinkEvaluator:
                 False,
                 (
                     LinkType.requires_python_mismatch,
-                    "1.12 Requires-Python == 3.6.5",
+                    "1.12 Requires-Python ==3.6.5,!=3.13.3",
                 ),
                 id="requires-python-mismatch",
             ),
@@ -144,9 +147,9 @@ class TestLinkEvaluator:
     )
     def test_evaluate_link(
         self,
-        py_version_info: Tuple[int, int, int],
+        py_version_info: tuple[int, int, int],
         ignore_requires_python: bool,
-        expected: Tuple[LinkType, str],
+        expected: tuple[LinkType, str],
     ) -> None:
         target_python = TargetPython(py_version_info=py_version_info)
         evaluator = LinkEvaluator(
@@ -159,7 +162,7 @@ class TestLinkEvaluator:
         )
         link = Link(
             "https://example.com/#egg=twine-1.12",
-            requires_python="== 3.6.5",
+            requires_python="!= 3.13.3, == 3.6.5",
         )
         actual = evaluator.evaluate_link(link)
         assert actual == expected
@@ -197,7 +200,7 @@ class TestLinkEvaluator:
         self,
         yanked_reason: str,
         allow_yanked: bool,
-        expected: Tuple[LinkType, str],
+        expected: tuple[LinkType, str],
     ) -> None:
         target_python = TargetPython(py_version_info=(3, 6, 4))
         evaluator = LinkEvaluator(
@@ -246,7 +249,7 @@ class TestLinkEvaluator:
         (64 * "c", ["1.0", "1.1", "1.2"]),
     ],
 )
-def test_filter_unallowed_hashes(hex_digest: str, expected_versions: List[str]) -> None:
+def test_filter_unallowed_hashes(hex_digest: str, expected_versions: list[str]) -> None:
     candidates = [
         make_mock_candidate("1.0"),
         make_mock_candidate("1.1", hex_digest=(64 * "a")),
@@ -432,7 +435,7 @@ class TestCandidateEvaluator:
     def test_get_applicable_candidates__hashes(
         self,
         specifier: SpecifierSet,
-        expected_versions: List[str],
+        expected_versions: list[str],
     ) -> None:
         """
         Test a non-None hashes value.
@@ -465,13 +468,13 @@ class TestCandidateEvaluator:
         )
         result = evaluator.compute_best_candidate(candidates)
 
-        assert result._candidates == candidates
+        assert result.all_candidates == candidates
         expected_applicable = candidates[:2]
         assert [str(c.version) for c in expected_applicable] == [
             "1.10",
             "1.11",
         ]
-        assert result._applicable_candidates == expected_applicable
+        assert result.applicable_candidates == expected_applicable
 
         assert result.best_candidate is expected_applicable[1]
 
@@ -488,8 +491,8 @@ class TestCandidateEvaluator:
         )
         result = evaluator.compute_best_candidate(candidates)
 
-        assert result._candidates == candidates
-        assert result._applicable_candidates == []
+        assert result.all_candidates == candidates
+        assert result.applicable_candidates == []
         assert result.best_candidate is None
 
     @pytest.mark.parametrize(
@@ -503,7 +506,7 @@ class TestCandidateEvaluator:
             (64 * "b", 0),
         ],
     )
-    def test_sort_key__hash(self, hex_digest: Optional[str], expected: int) -> None:
+    def test_sort_key__hash(self, hex_digest: str | None, expected: int) -> None:
         """
         Test the effect of the link's hash on _sort_key()'s return value.
         """
@@ -528,7 +531,7 @@ class TestCandidateEvaluator:
         ],
     )
     def test_sort_key__is_yanked(
-        self, yanked_reason: Optional[str], expected: int
+        self, yanked_reason: str | None, expected: int
     ) -> None:
         """
         Test the effect of is_yanked on _sort_key()'s return value.
@@ -734,8 +737,8 @@ class TestPackageFinder:
         self,
         allow_yanked: bool,
         ignore_requires_python: bool,
-        only_binary: Set[str],
-        expected_formats: FrozenSet[str],
+        only_binary: set[str],
+        expected_formats: frozenset[str],
     ) -> None:
         # Create a test TargetPython that we can check for.
         target_python = TargetPython(py_version_info=(3, 7))
@@ -819,7 +822,7 @@ class TestPackageFinder:
 
 
 @pytest.mark.parametrize(
-    ("fragment", "canonical_name", "expected"),
+    "fragment, canonical_name, expected",
     [
         # Trivial.
         ("pip-18.0", "pip", 3),
@@ -851,7 +854,7 @@ def test_find_name_version_sep(
 
 
 @pytest.mark.parametrize(
-    ("fragment", "canonical_name"),
+    "fragment, canonical_name",
     [
         # A dash must follow the package name.
         ("zope.interface4.5.0", "zope-interface"),
@@ -868,7 +871,7 @@ def test_find_name_version_sep_failure(fragment: str, canonical_name: str) -> No
 
 
 @pytest.mark.parametrize(
-    ("fragment", "canonical_name", "expected"),
+    "fragment, canonical_name, expected",
     [
         # Trivial.
         ("pip-18.0", "pip", "18.0"),
@@ -897,7 +900,7 @@ def test_find_name_version_sep_failure(fragment: str, canonical_name: str) -> No
     ],
 )
 def test_extract_version_from_fragment(
-    fragment: str, canonical_name: str, expected: Optional[str]
+    fragment: str, canonical_name: str, expected: str | None
 ) -> None:
     version = _extract_version_from_fragment(fragment, canonical_name)
     assert version == expected
