@@ -1,8 +1,11 @@
+from __future__ import annotations
+
 import functools
 import os
 import subprocess
 import sys
-from typing import Any, Dict, Iterable, List, Optional, Tuple
+from collections.abc import Iterable
+from typing import Any
 
 import pytest
 
@@ -50,7 +53,7 @@ def reset_keyring() -> Iterable[None]:
     ],
 )
 def test_get_credentials_parses_correctly(
-    input_url: str, url: str, username: Optional[str], password: Optional[str]
+    input_url: str, url: str, username: str | None, password: str | None
 ) -> None:
     auth = MultiDomainBasicAuth()
     get = auth._get_url_and_credentials
@@ -163,9 +166,9 @@ class KeyringModuleV1:
     """
 
     def __init__(self) -> None:
-        self.saved_passwords: List[Tuple[str, str, str]] = []
+        self.saved_passwords: list[tuple[str, str, str]] = []
 
-    def get_password(self, system: str, username: str) -> Optional[str]:
+    def get_password(self, system: str, username: str) -> str | None:
         if system == "example.com" and username:
             return username + "!netloc"
         if system == "http://example.com/path2/" and username:
@@ -191,7 +194,7 @@ class KeyringModuleV1:
 def test_keyring_get_password(
     monkeypatch: pytest.MonkeyPatch,
     url: str,
-    expect: Tuple[Optional[str], Optional[str]],
+    expect: tuple[str | None, str | None],
 ) -> None:
     keyring = KeyringModuleV1()
     monkeypatch.setitem(sys.modules, "keyring", keyring)
@@ -275,7 +278,7 @@ def test_keyring_get_password_username_in_index(
 def test_keyring_set_password(
     monkeypatch: pytest.MonkeyPatch,
     response_status: int,
-    creds: Tuple[str, str, bool],
+    creds: tuple[str, str, bool],
     expect_save: bool,
 ) -> None:
     keyring = KeyringModuleV1()
@@ -336,7 +339,7 @@ class KeyringModuleV2:
     def get_password(self, system: str, username: str) -> None:
         pytest.fail("get_password should not ever be called")
 
-    def get_credential(self, system: str, username: str) -> Optional[Credential]:
+    def get_credential(self, system: str, username: str) -> Credential | None:
         if system == "http://example.com/path2/":
             return self.Credential("username", "url")
         if system == "example.com":
@@ -353,7 +356,7 @@ class KeyringModuleV2:
     ],
 )
 def test_keyring_get_credential(
-    monkeypatch: pytest.MonkeyPatch, url: str, expect: Tuple[str, str]
+    monkeypatch: pytest.MonkeyPatch, url: str, expect: tuple[str, str]
 ) -> None:
     monkeypatch.setitem(sys.modules, "keyring", KeyringModuleV2())
     auth = MultiDomainBasicAuth(
@@ -401,13 +404,13 @@ class KeyringSubprocessResult(KeyringModuleV1):
 
     def __call__(
         self,
-        cmd: List[str],
+        cmd: list[str],
         *,
-        env: Dict[str, str],
-        stdin: Optional[Any] = None,
-        stdout: Optional[Any] = None,
-        input: Optional[bytes] = None,
-        check: Optional[bool] = None,
+        env: dict[str, str],
+        stdin: Any | None = None,
+        stdout: Any | None = None,
+        input: bytes | None = None,
+        check: bool | None = None,
     ) -> Any:
         if cmd[1] == "get":
             assert stdin == -3  # subprocess.DEVNULL
@@ -456,7 +459,7 @@ class KeyringSubprocessResult(KeyringModuleV1):
 def test_keyring_cli_get_password(
     monkeypatch: pytest.MonkeyPatch,
     url: str,
-    expect: Tuple[Optional[str], Optional[str]],
+    expect: tuple[str | None, str | None],
 ) -> None:
     monkeypatch.setattr(pip._internal.network.auth.shutil, "which", lambda x: "keyring")
     monkeypatch.setattr(
@@ -490,7 +493,7 @@ def test_keyring_cli_get_password(
 def test_keyring_cli_set_password(
     monkeypatch: pytest.MonkeyPatch,
     response_status: int,
-    creds: Tuple[str, str, bool],
+    creds: tuple[str, str, bool],
     expect_save: bool,
 ) -> None:
     monkeypatch.setattr(pip._internal.network.auth.shutil, "which", lambda x: "keyring")
