@@ -1,12 +1,15 @@
+from __future__ import annotations
+
 import contextlib
 import email.message
 import os
 import shutil
 import sys
 import tempfile
+from collections.abc import Iterator
 from functools import partial
 from pathlib import Path
-from typing import Iterator, Optional, Set, Tuple, cast
+from typing import cast
 from unittest import mock
 
 import pytest
@@ -14,6 +17,7 @@ import pytest
 from pip._vendor.packaging.markers import Marker
 from pip._vendor.packaging.requirements import Requirement
 
+from pip._internal.build_env import SubprocessBuildEnvironmentInstaller
 from pip._internal.cache import WheelCache
 from pip._internal.commands import create_command
 from pip._internal.commands.install import InstallCommand
@@ -47,6 +51,7 @@ from pip._internal.req.req_file import (
     handle_requirement_line,
 )
 from pip._internal.resolution.legacy.resolver import Resolver
+from pip._internal.utils.urls import path_to_url
 
 from tests.lib import TestData, make_test_finder, requirements_file, wheel
 
@@ -84,7 +89,7 @@ class TestRequirementSet:
         self,
         finder: PackageFinder,
         require_hashes: bool = False,
-        wheel_cache: Optional[WheelCache] = None,
+        wheel_cache: WheelCache | None = None,
     ) -> Iterator[Resolver]:
         make_install_req = partial(
             install_req_from_req_string,
@@ -94,11 +99,13 @@ class TestRequirementSet:
         session = PipSession()
 
         with get_build_tracker() as tracker:
+            installer = SubprocessBuildEnvironmentInstaller(finder)
             preparer = RequirementPreparer(
                 build_dir=os.path.join(self.tempdir, "build"),
                 src_dir=os.path.join(self.tempdir, "src"),
                 download_dir=None,
                 build_isolation=True,
+                build_isolation_installer=installer,
                 check_build_deps=False,
                 build_tracker=tracker,
                 session=session,
@@ -109,6 +116,7 @@ class TestRequirementSet:
                 lazy_wheel=False,
                 verbosity=0,
                 legacy_resolver=True,
+                resume_retries=0,
             )
             yield Resolver(
                 preparer=preparer,
@@ -217,16 +225,12 @@ class TestRequirementSet:
         dir_path = data.packages.joinpath("FSPkg")
         reqset.add_unnamed_requirement(
             get_processed_req_from_line(
-                f"file://{dir_path}",
+                path_to_url(str(dir_path)),
                 lineno=2,
             )
         )
         finder = make_test_finder(find_links=[data.find_links])
 
-        sep = os.path.sep
-        if sep == "\\":
-            sep = "\\\\"  # This needs to be escaped for the regex
-
         with self._basic_resolver(finder, require_hashes=True) as resolver:
             with pytest.raises(
                 HashErrors,
@@ -237,7 +241,7 @@ class TestRequirementSet:
                     r"file \(line 1\)\)\n"
                     r"Can't verify hashes for these file:// requirements because "
                     r"they point to directories:\n"
-                    rf"    file://.*{sep}data{sep}packages{sep}FSPkg "
+                    r"    file://.*/data/packages/FSPkg "
                     r"\(from -r file \(line 2\)\)"
                 ),
             ):
@@ -815,7 +819,7 @@ class TestInstallRequirement:
         ],
     )
     def test_install_req_extend_extras(
-        self, inp: str, extras: Set[str], out: str
+        self, inp: str, extras: set[str], out: str
     ) -> None:
         """
         Test behavior of install_req_extend_extras
@@ -996,8 +1000,8 @@ def test_looks_like_path_win(args: str, expected: bool) -> None:
 def test_get_url_from_path(
     isdir_mock: mock.Mock,
     isfile_mock: mock.Mock,
-    args: Tuple[str, str],
-    mock_returns: Tuple[bool, bool],
+    args: tuple[str, str],
+    mock_returns: tuple[bool, bool],
     expected: None,
 ) -> None:
     isdir_mock.return_value = mock_returns[0]
