@@ -1,12 +1,15 @@
+from __future__ import annotations
+
 import codecs
 import collections
 import logging
 import os
 import re
 import textwrap
+from collections.abc import Iterator
 from optparse import Values
 from pathlib import Path
-from typing import Any, Iterator, List, Optional, Protocol, Tuple, Union
+from typing import Any, Protocol
 from unittest import mock
 
 import pytest
@@ -54,10 +57,10 @@ def options(session: PipSession) -> mock.Mock:
 
 
 def parse_reqfile(
-    filename: Union[Path, str],
+    filename: Path | str,
     session: PipSession,
-    finder: Optional[PackageFinder] = None,
-    options: Optional[Values] = None,
+    finder: PackageFinder | None = None,
+    options: Values | None = None,
     constraint: bool = False,
     isolated: bool = False,
 ) -> Iterator[InstallRequirement]:
@@ -197,11 +200,11 @@ class LineProcessor(Protocol):
         line: str,
         filename: str,
         line_number: int,
-        finder: Optional[PackageFinder] = None,
-        options: Optional[Values] = None,
-        session: Optional[PipSession] = None,
+        finder: PackageFinder | None = None,
+        options: Values | None = None,
+        session: PipSession | None = None,
         constraint: bool = False,
-    ) -> List[InstallRequirement]: ...
+    ) -> list[InstallRequirement]: ...
 
 
 @pytest.fixture
@@ -210,11 +213,11 @@ def line_processor(monkeypatch: pytest.MonkeyPatch, tmpdir: Path) -> LineProcess
         line: str,
         filename: str,
         line_number: int,
-        finder: Optional[PackageFinder] = None,
-        options: Optional[Values] = None,
-        session: Optional[PipSession] = None,
+        finder: PackageFinder | None = None,
+        options: Values | None = None,
+        session: PipSession | None = None,
         constraint: bool = False,
-    ) -> List[InstallRequirement]:
+    ) -> list[InstallRequirement]:
         if session is None:
             session = PipSession()
 
@@ -587,7 +590,7 @@ class TestProcessLine:
 
         def get_file_content(
             filename: str, *args: Any, **kwargs: Any
-        ) -> Tuple[None, str]:
+        ) -> tuple[None, str]:
             if filename == req_file:
                 return None, "-r reqs.txt"
             elif filename == "http://me.com/me/reqs.txt":
@@ -656,7 +659,7 @@ class TestProcessLine:
 
         def get_file_content(
             filename: str, *args: Any, **kwargs: Any
-        ) -> Tuple[None, str]:
+        ) -> tuple[None, str]:
             if filename == str(req_file):
                 return None, f"-r {nested_req_file}"
             elif filename == nested_req_file:
@@ -1033,8 +1036,9 @@ class TestParseRequirements:
 
         # it's hard to rely on a locale definitely existing for testing
         # so patch things out for simplicity
-        with caplog.at_level(logging.WARNING), mock.patch(
-            "locale.getpreferredencoding", return_value=locale_encoding
+        with (
+            caplog.at_level(logging.WARNING),
+            mock.patch("locale.getpreferredencoding", return_value=locale_encoding),
         ):
             reqs = tuple(parse_reqfile(req_file.resolve(), session=session))
 
@@ -1065,7 +1069,8 @@ class TestParseRequirements:
         req_file = tmpdir / "requirements.txt"
         req_file.write_bytes(data)
 
-        with pytest.raises(UnicodeDecodeError), mock.patch(
-            "locale.getpreferredencoding", return_value=encoding
+        with (
+            pytest.raises(UnicodeDecodeError),
+            mock.patch("locale.getpreferredencoding", return_value=encoding),
         ):
             next(parse_reqfile(req_file.resolve(), session=session))
